@@ -326,14 +326,19 @@ def get_gem( cc, capa ):
         aex = (ex,exd,mine,maxe,ex10)
         print(f"I...  exposure         {ex:4d};  range({mine:4d},{maxe:5d}) def: {exd} {ex10:.5f}")
 
+
+    # bad sonix camera- crazy default values...
     if "gain" in capa:
         ga = cc.get_gain()
         gad = cc.getdef_gain()
         ming = cc.getmin_gain()
         maxg = cc.getmax_gain()
         ga10 = (ga-ming)/(maxg-ming)
+        if (gad>maxg)or (gad<ming): ### if bad values
+            gad=ming
         aga = (ga,gad,ming,maxg,ga10)
 
+
         print(f"I...  gain             {ga:4d};  range({ming:4d},{maxg:5d}) def: {gad} {ga10:.5f}")
 
 
